#
# spec file for package meson
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name   mesonbuild
Name:           meson
Version:        0.37.1
Release:        2.1
Summary:        Python-based build system
License:        Apache-2.0
Group:          Development/Tools/Building
Url:            http://mesonbuild.com/
Source:         https://github.com/%{_name}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/%{_name}/%{name}/releases/download/%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
# PATCH-FIX-OPENSUSE meson-suse-ify-macros.patch dimstar@opensuse.org -- Make the macros non-RetHat specific. So far we do not have sep. {C,CXX,F}FLAGS
Patch0:         meson-suse-ify-macros.patch
BuildRequires:  bison
BuildRequires:  boost-devel
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gcc-obj-c++
BuildRequires:  gcc-objc
BuildRequires:  gettext
BuildRequires:  git
BuildRequires:  gtk-doc
BuildRequires:  itstool
BuildRequires:  java-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  mono-core
BuildRequires:  mono-devel
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  python3 >= 3.4
BuildRequires:  python3-devel
BuildRequires:  python3-gobject
BuildRequires:  python3-setuptools
BuildRequires:  vala
BuildRequires:  wxWidgets-devel >= 3.0.0
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(zlib)
Requires:       ninja
# meson-gui was last used in openSUSE Leap 42.1.
Provides:       %{name}-gui = %{version}
Obsoletes:      %{name}-gui < %{version}
BuildArch:      noarch

%description
Meson is a build system designed to optimise programmer productivity.
It aims to do this by providing support for software development
tools and practices, such as unit tests, coverage reports, Valgrind,
CCache and the like. Supported languages include C, C++, Fortran,
Java, Rust. Build definitions are written in a non-turing complete
Domain Specific Language.

%prep
%setup -q
%patch0 -p1

# Lack of gtest, gmock, gnustep.
rm -rf "test cases/frameworks/2 gtest" \
  "test cases/frameworks/3 gmock/"     \
  "test cases/objc/2 nsstring"

%build
python3 setup.py build

%install
python3 setup.py install \
  --root=%{buildroot} --prefix=%{_prefix}

install -Dpm 0644 data/macros.%{name} \
  %{buildroot}%{_rpmconfigdir}/macros.d/macros.%{name}

%check
export MESON_PRINT_TEST_OUTPUT=1
export SUSE_ASNEEDED=0
python3 run_tests.py

%files
%defattr(-,root,root)
%doc authors.txt contributing.txt COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}conf
%{_bindir}/%{name}introspect
%{_bindir}/%{name}test
%{_bindir}/wraptool
%{python3_sitelib}/%{_name}/
%{python3_sitelib}/%{name}-*
%{_rpmconfigdir}/macros.d/macros.%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}conf.1%{?ext_man}
%{_mandir}/man1/%{name}introspect.1%{?ext_man}
%{_mandir}/man1/wraptool.1%{?ext_man}

%changelog
* Tue Jan 10 2017 dimstar@opensuse.org
- Add meson-suse-ify-macros.patch: Make the meson macros also work
  on openSUSE. We do not (yet?) have separate macros for CFLAGS,
  CXXFLAGS, FFLAGS and LDFLAGS, but only carry optflags. This is no
  issue, since openSUSE so far only added flags that work accross
  compilers/languages. This might change in the future, making the
  patch obsolete.
* Sun Jan  1 2017 sor.alexei@meowr.ru
- Update to version 0.37.1:
  * No changelog available.
* Sun Jan  1 2017 jengelh@inai.de
- Trim boasting words from descriptions. Add to description two
  points from the feature list.
* Mon Dec 19 2016 dev@antergos.com
- Update to version 0.37.0:
  * Mesontest: a new testing tool that allows you to run your
    tests in many different ways.
  * New shared_module function allows shared modules creation.
  * GNOME module now detects required programs and prints useful
    errors if any are missing.
  * GNOME module uses depfile support available in GLib >= 2.52.0.
  * i18n module has a new merge_file() function for creating
    translated files.
  * LLVM IR compilation is now supported.
  * .wrap files for subprojects can now include a separate push
    URL to allow developers to push changes directly from a
    subproject git checkout.
  * Multiple version restrictions while searching for pkg-config
    dependencies is now supported.
  * Support for localstatedir has been added.
  * You can now pass arguments to install scripts added with
    meson.add_install_script().
  * Added new options sbindir and infodir that can be used for
    installation.
- Remove meson-0.36.0-fix-old-pkgconfig-test.patch.
* Sat Dec 10 2016 sor.alexei@meowr.ru
- Add meson-0.36.0-fix-old-pkgconfig-test.patch: tests/common/51:
  Skip validate if pkg-config is too old (commit 2f804e9).
* Tue Nov 22 2016 dimstar@opensuse.org
- Update to version 0.36.0:
  + Add option to run under gdb.
  + Always specify installed data with a File object
    (gh#mesonbuild/meson#858).
  + Made has_function survive optimization flags
    (gh#mesonbuild/meson#1053).
  + Can give many alternative names to find_program to simplify
    searching.
  + Can set compiler arguments in Java.
- Export SUSE_ASNEEDED=0 when running the test suite: linking the
  test libraries/binaries is not done optimally.
* Tue Oct 18 2016 sor.alexei@meowr.ru
- Update to version 0.35.1:
  * No changelog available.
* Fri Oct 14 2016 zaitor@opensuse.org
- Update to version 0.35.0:
  + No changelog available from upstream.
- Changes from version 0.34.0:
  + No changelog available from upstream.
- Drop meson-633.patch and meson-typelib-install.patch : Fixed
  upstream.
* Wed Aug 17 2016 dimstar@opensuse.org
- Update to version 0.33.0:
  + Correctly install .typelib files to libdir.
  + Add option for as-needed link option.
  + Print the CFLAGS/LDFLAGS/etc inherited from the environment.
  + Only append compile flags to the link flags when appropriate.
- Add meson-633.patch: Handle both DT_RPATH as well as DT_RUNPATH
  when fixing rpath settings (gh#mesonbuild/meson#663).
- Add meson-typelib-install.patch: Fix installation path for
  gpobject introspection typelib files.
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 0.32.0:
  * No changelog available.
- Remove meson-gui package: GUI was removed upstream.
* Mon May  9 2016 jengelh@inai.de
- Avoid unnecessary bashism in %%install script (run with /bin/sh)
* Sat May  7 2016 sor.alexei@meowr.ru
- Update to version 0.31.0.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.29.0.
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 0.28.0.
* Fri Dec  4 2015 sor.alexei@meowr.ru
- Update to 0.27.0.
* Sun Sep 13 2015 sor.alexei@meowr.ru
- Update to 0.26.0.
- Use signed tarball.
* Sun Jul 12 2015 sor.alexei@meowr.ru
- Initial package based on the work of Igor Gnatenko.
